#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const program = require("commander");
const literator_1 = require("./literator");
const path_1 = require("path");
const fs_1 = require("fs");
const fs_extra_1 = require("fs-extra");
const cosmiconfig_1 = require("cosmiconfig");
const cosmiconfig_typescript_loader_1 = require("@endemolshinegroup/cosmiconfig-typescript-loader");
const package_json = fs_extra_1.readJSONSync(path_1.resolve(__dirname, "../../package.json"));
program.version(package_json.version);
program.option("-w, --watch", "compose file or files in directory in watch mode");
program.option("-clean, --clean", "remove generated files");
program.parse(process.argv);
const args = program.args;
if (args.length === 0) {
    program.help();
}
else {
    const [target] = args;
    if (target) {
        if (program.clean) {
            literator_1.CrossoutDirectory(target);
        }
        else {
            Transcribe(target);
        }
    }
}
function Transcribe(target) {
    //
    // find config
    const explorer = cosmiconfig_1.cosmiconfig("svelte-draft", {
        searchPlaces: [`svelte-draft.config.ts`],
        loaders: {
            ".ts": cosmiconfig_typescript_loader_1.default,
        },
    });
    explorer.search().then(config_info => {
        let config = { DSLs: [] };
        if (config_info && !config_info.isEmpty) {
            config = Object.assign(Object.assign({}, config), config_info.config);
        }
        //
        const working_directory = process.cwd();
        const path = path_1.resolve(working_directory, target);
        if (fs_1.lstatSync(path).isDirectory()) {
            program.watch ? literator_1.InspectDirectory(path, config) : literator_1.ComposeDirectory(path, config);
        }
        else {
            program.watch ? literator_1.InspectFile(path, config) : literator_1.ComposeFile(path, config);
        }
    });
}
